# Arianna's first package


[![PyPI Status](https://img.shields.io/pypi/v/arianna-first-package.svg)](https://pypi.python.org/pypi/arianna-first-package)
[![Build Status](https://github.com/AriannaBonazza/arianna-first-package/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/AriannaBonazza/arianna-first-package/actions?query=workflow%3Abuild)
[![Documentation Status](https://github.com/AriannaBonazza/arianna-first-package/actions/workflows/docs.yml/badge.svg?branch=main)](https://github.com/AriannaBonazza/arianna-first-package/actions?query=workflow%3Adocs)
[![License](https://img.shields.io/github/license/AriannaBonazza/arianna-first-package)](https://github.com/AriannaBonazza/arianna-first-package/blob/main/LICENSE)
[![Code Coverage](https://codecov.io/gh/AriannaBonazza/arianna-first-package/branch/main/graphs/badge.svg)](https://codecov.io/gh/AriannaBonazza/arianna-first-package/tree/main)

Arianna's first package is a simple Python package for learning puropses.


- Free software: MIT license
- Documentation: https://AriannaBonazza.github.io/arianna-first-package/.


## Features

- TODO

## Credits

This package was created with [Cookiecutter][CC] and the [Package Helper 3][PH3] project template during my stage at Swapcard.

[CC]: https://github.com/audreyr/cookiecutter
[PH3]: https://balouf.github.io/package-helper-3/
